==> haskell-hspec-megaparsec-2.0.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.1
id: hspec-megaparsec-2.0.1-86tkgucsyPiH3w8geVJtCX
key: hspec-megaparsec-2.0.1-86tkgucsyPiH3w8geVJtCX
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 6dde668711eea8d6df4cc26b8d216fde
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.1
hs-libraries: HShspec-megaparsec-2.0.1-86tkgucsyPiH3w8geVJtCX
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.0.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.1
id: hspec-megaparsec-2.0.1-8RsdjGfZqJf9kyozRW1rcT
key: hspec-megaparsec-2.0.1-8RsdjGfZqJf9kyozRW1rcT
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 519ed3d7dc5668414c1c9a7500137f82
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.1
hs-libraries: HShspec-megaparsec-2.0.1-8RsdjGfZqJf9kyozRW1rcT
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
    megaparsec-7.0.5-CZJNdrmae7v2Ggr9WXcTF8
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
